==> vtigercrm-5.0.3.tgz: vtigercrm/modules/Home/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header: /advent/projects/wesat/vtiger_crm/sugarcrm/modules/Home/language/en_us.lang.php,v 1.5 2005/03/04 15:18:47 jack Exp $
 * Description:  Defines the English language pack 
 ********************************************************************************/
 
$mod_strings = Array(
'LBL_NEW_FORM_TITLE'=>'New Contact',
'LBL_FIRST_NAME'=>'First Name:',
'LBL_LAST_NAME'=>'Last Name:',
'LBL_LIST_LAST_NAME'=>'Last Name',
'LBL_ACCOUNT_NAME'=>'Account Name:',
'LBL_LIST_ACCOUNT_NAME'=>'Account Name',
'LBL_PHONE'=>'Phone:',
'LBL_EMAIL_ADDRESS'=>'Email:',
'LBL_TOTAL'=>'Total : ',

'LBL_MY_HOME'=>'My Home',
'LBL_MODIFIED_TIME'=>'Modified Time',
'LBL_LOGIN_ID'=>'ID',
'LBL_MODIFIED_BY'=>'Modified By',
'LBL_TYPE'=>'Type',

'LBL_PIPELINE_FORM_TITLE'=>'My Pipeline',

'ERR_ONE_CHAR'=>'Please enter at least one letter or number for your search ...',

'LBL_OPEN_TASKS'=>'My Open Tasks',

'LBL_LEADS_BY_SOURCE'=>'Leads By Source',
'LBL_LEADS_BY_STATUS'=>'Leads By Status',

'LBL_UPCOMING_EVENTS'=>'Upcoming Activities',
'LBL_PENDING_EVENTS'=>'Pending Activities',
'LBL_SINGLE_PENDING_EVENT'=>'Event for Last Ten Days',
'LBL_MULTIPLE_PENDING_EVENTS'=>'Events for Last Ten Days',

'recordsforuser'=>'Records for',

'Today'=>'Today',
'This Week'=>'This Week',
'This Month'=>'This Month',
'This Year'=>'This Year',
'Last Week'=>'Last Week',
'Last 2 Days'=>'Last 2 Days',
'Last Ten Days'=>'Last Ten Days',


);

?>

==> vtigercrm-5.0.4p0.tgz: vtigercrm/modules/Home/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header: /advent/projects/wesat/vtiger_crm/sugarcrm/modules/Home/language/en_us.lang.php,v 1.5 2005/03/04 15:18:47 jack Exp $
 * Description:  Defines the English language pack 
 ********************************************************************************/
 
$mod_strings = Array(
'LBL_NEW_FORM_TITLE'=>'New Contact',
'LBL_FIRST_NAME'=>'First Name:',
'LBL_LAST_NAME'=>'Last Name:',
'LBL_LIST_LAST_NAME'=>'Last Name',
'LBL_ACCOUNT_NAME'=>'Account Name:',
'LBL_LIST_ACCOUNT_NAME'=>'Account Name',
'LBL_PHONE'=>'Phone:',
'LBL_EMAIL_ADDRESS'=>'Email:',
'LBL_TOTAL'=>'Total : ',

'LBL_MY_HOME'=>'My Home',
'LBL_MODIFIED_TIME'=>'Modified Time',
'LBL_LOGIN_ID'=>'ID',
'LBL_MODIFIED_BY'=>'Modified By',
'LBL_TYPE'=>'Type',

'LBL_PIPELINE_FORM_TITLE'=>'My Pipeline',

'ERR_ONE_CHAR'=>'Please enter at least one letter or number for your search ...',

'LBL_OPEN_TASKS'=>'My Open Tasks',

'LBL_LEADS_BY_SOURCE'=>'Leads By Source',
'LBL_LEADS_BY_STATUS'=>'Leads By Status',

'LBL_UPCOMING_EVENTS'=>'Upcoming Activities',
'LBL_PENDING_EVENTS'=>'Pending Activities',
'LBL_SINGLE_PENDING_EVENT'=>'Event for Last Ten Days',
'LBL_MULTIPLE_PENDING_EVENTS'=>'Events for Last Ten Days',

'recordsforuser'=>'Records for',

'Today'=>'Today',
'This Week'=>'This Week',
'This Month'=>'This Month',
'This Year'=>'This Year',
'Last Week'=>'Last Week',
'Last 2 Days'=>'Last 2 Days',
'Last Ten Days'=>'Last Ten Days',

// Added/Updated for vtiger CRM 5.0.4 
'TITLE_AJAX_CSS_POPUP_CHAT'=>'Ajax Css-Popup chat',
'User List'=>'User List',

);

?>
